#ifndef _uptime_h
#define _uptime_h

struct Uptime
{
  int days;
  int seconds;
};


#endif // _uptime_h
